XenditInvokeParameters<T> class
Constructors
Properties
-
builder
→ FutureOr<
T> Function(Map result) -
final
- endpoint → String
-
GET https://api.xendit.co/v2/invoices/{invoice_id}
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headers → Map?
-
final
- isThrowOnError → bool
-
final
- parameters → Map
-
final
-
queryParameters
→ Map<
String, dynamic> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- specialTypeSucces → String
-
final
- xenditApiKey → String
-
final
Methods
-
copyWith(
{String? endpoint, String? xenditApiKey, String? specialTypeSucces, bool? isThrowOnError, Map< String, dynamic> ? queryParameters, Map? headers, String? method, Map? parameters, FutureOr<T> builder(Map result)?}) → XenditInvokeParameters -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited